Summary: A library of functions for manipulating TIFF format image files.
Name: libtiff

%global momorel 5

Version: 3.5.7
Release: %{momorel}m
License: see "COPYRIGHT"
Group: System Environment/Libraries
URL: http://www.libtiff.org/

%NoSource 0 ftp://ftp.remotesensing.org/pub/libtiff/tiff-v%{version}.tar.gz 82243b5ae9b7c9e492aeebc501680990

Patch0: tiff-v3.5-shlib.patch
Patch1: libtiff-v3.4-arm.patch
Patch2: libtiff-v3.5.4-codecs.patch
Patch3: libtiff-v3.5.4-mandir.patch
Patch4: libtiff-v3.5.5-buildroot.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: zlib-devel >= 1.1.4-5m
BuildRequires: zlib >= 1.1.4-5m 
BuildRequires: libjpeg-devel

%define LIBVER %(echo %{version} | cut -f-2 -d.)

%description
The libtiff package contains a library of functions for manipulating 
TIFF (Tagged Image File Format) image format files.  TIFF is a widely
used file format for bitmapped images.  TIFF files usually end in the
.tif extension and they are often quite large.

The libtiff package should be installed if you need to manipulate TIFF
format image files.

%package devel
Summary: Development tools for programs which will use the libtiff library.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files and static libraries for
developing programs which will manipulate TIFF format image files
using the libtiff library.

If you need to develop programs which will manipulate TIFF format
image files, you should install this package.  You'll also need to
install the libtiff package.
#'

%prep
%setup -q -n tiff-v%{version}
%patch0 -p1 -b .shlib
%patch1 -p1 -b .arm
%patch2 -p1 -b .codecs
%patch3 -p1 -b .mandir
%patch4 -p1 -b .buildroot
find . -type d -name CVS | xargs -r rm -frv

%build
./configure --target=%{_target_platform} \
  --with-GCOPTS="%{optflags}" << EOF 
no
%{_bindir}
%{_libdir}
%{_includedir}
%{_mandir}
$RPM_DOC_DIR/%{name}-%{version}
bsd-source-cat
yes
EOF
(
  cd libtiff
  %__ln_s libtiff.so.%{LIBVER} libtiff.so
)
%global _make_env MAKE="make LDOPTS='-s'"
%make

%install
[ "%{buildroot}" != "/" ] && %__rm -rf %{buildroot}
%__mkdir_p %{buildroot}/{%{_bindir},%{_includedir},%{_mandir}}
make install
%__install -m 755 libtiff/libtiff.so.%{LIBVER} %{buildroot}%{_libdir}
%__ln_s -f libtiff.so.%{LIBVER} %{buildroot}%{_libdir}/libtiff.so

%clean
[ "%{buildroot}" != "/" ] && %__rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(0755,root,root)
%doc COPYRIGHT README VERSION
%{_libdir}/libtiff.so.*
%{_bindir}/*
%{_mandir}/man1/*

%files devel
%defattr(-,root,root)
%doc TODO html
%{_libdir}/libtiff.so
%{_libdir}/libtiff.a
%{_includedir}/*
%{_mandir}/man3/*

%changelog
* Mon Mar 22 2004 Toru Hoshina <t@momonga-linux.org>
- (3.5.7-5m)
- revised spec for enabling rpm 4.2.

* Thu Nov 20 2003 zunda <zunda at freeshell.org>
- (3.5.7-4m)
- adapt the License: preamble for the Momonga Linux license
  expression unification policy (draft)

* Mon Oct 27 2003 Kenta MURATA <muraken2@nifty.com>
- (3.5.7-3m)
- pretty spec file.

* Mon Apr 07 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.5.7-3m)
- rebuild against zlib 1.1.4-5m
- use rpm macros

* Wed Feb  6 2002 Kazuhiko <kazuhiko@kondara.org>
- (3.5.7-2k)
- change the URI of Source0

* Mon Sep 17 2001 MATSUDA, Daiki
- (3.5.5-10k)
- modify spec file for jitterbug #888

* Wed Jul 05 2000 Toru Hoshina <t@kondara.org>
- rebuild against glibc-2.1.90, X-4.0, rpm-3.0.5.

* Tue Jun 20 2000 Kenzi Cano <kc@furukawa.ch.kagu.sut.ac.jp>
- up to 3.5.5

* Mon Jun 12 2000 Nalin Dahyabhai <nalin@redhat.com>
- remove CVS repo info from data directories

* Thu May 18 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix build rooting
- fix syntax error in configure script
- move man pages to %{_mandir}

* Sun Apr 02 2000 Takaaki Tabuchi <tab@kondara.org>
- merge redhat-6.2 (3.5.4-5).

* Sat Feb 05 2000 Nalin Dahyabhai <nalin@redhat.com>
- set MANDIR=man3 to make multifunction man pages friendlier

* Mon Jan 31 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix URLs

* Fri Jan 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- link shared library against libjpeg and libz

* Tue Jan 18 2000 Nalin Dahyabhai <nalin@redhat.com>
- enable zip and jpeg codecs
- change defattr in normal package to 0755
- add defattr to -devel package

* Thu Jan 13 2000 Takaaki Tabuchi <tab@kondara.org>
- be able to rebuild non-root user.
- add %defattr(-,root,root).

* Wed Dec 22 1999 Bill Nottingham <notting@redhat.com>
- update to 3.5.4

* Mon Nov 8 1999 Toru Hoshina <t@kondara.org>
- be a NoSrc :-P

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 6)

* Wed Jan 13 1999 Cristian Gafton <gafton@redhat.com>
- build for glibc 2.1

* Wed Jun 10 1998 Prospector System <bugs@redhat.com>
- translations modified for de

* Wed Jun 10 1998 Michael Fulbright <msf@redhat.com>
- rebuilt against fixed jpeg libs (libjpeg-6b)

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Mon Oct 13 1997 Donnie Barnes <djb@redhat.com>
- new version to replace the one from libgr
- patched for glibc
- added shlib support

